package com.mygdx.game;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.Input;
import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.graphics.g2d.Sprite;
import com.badlogic.gdx.graphics.g2d.SpriteBatch;

public class Actor {
    protected static final int SPEED = 4;
    protected static final int DOWN = 0;
    protected static final int RIGHT = 1;
    protected static final int UP = 2;
    protected static final int LEFT = 3;
    protected float x, y;
    protected int step, direction;
    protected Sprite sprite[][];
    protected boolean moved;
    protected final int maxCount = 10;
    protected int count;
    protected MyGdxGame game;
    protected Sprite img;

    Actor(MyGdxGame game, float x, float y, String filename) {
        this.game = game;
        this.x = x;
        this.y = y;
        sprite = new Sprite[4][2];
        for (int dir = 0; dir < 4; dir++) {
            for (int stp = 0; stp < 2; stp++) {
                sprite[dir][stp] = new Sprite(
                        new Texture(filename +
                                "." + dir + "." + stp + ".png"));
            }
        }
        img = sprite[0][0];
    }

    void execute() {
        moved = false;
        if (Gdx.input.isKeyPressed(Input.Keys.DOWN)) {
            direction = DOWN;
            y -= SPEED;
            moved = true;
        } else if (Gdx.input.isKeyPressed(Input.Keys.UP)) {
            direction = UP;
            y += SPEED;
            moved = true;
        } else if (Gdx.input.isKeyPressed(Input.Keys.RIGHT)) {
            direction = RIGHT;
            x += SPEED;
            moved = true;
        } else if (Gdx.input.isKeyPressed(Input.Keys.LEFT)) {
            direction = LEFT;
            x -= SPEED;
            moved = true;
        }
        count++;
        if (count >= maxCount) {
            count = 0;
            if (moved) step = (step == 0) ? 1 : 0;
        }
        int w = (int) img.getWidth();
        int h = (int) img.getHeight();

        if (x < 0) x = 0;
        if (x > game.W - w) x = game.W - w;
        if (y < 0) y = 0;
        if (y > game.H - h) y = game.H - h;
    }

    void draw(SpriteBatch batch) {
        img = sprite[direction][step];
        img.setPosition(x, y);
        img.draw(batch);
    }

    void dispose() {
        for (int dir = 0; dir < 4; dir++) {
            for (int stp = 0; stp < 2; stp++) {
                sprite[dir][stp].getTexture().dispose();
            }
        }
    }
}

